/// `CallAppSettings` is a class that contains the app settings for the call.
///
/// It includes the `appId`, `region`, and `host` for the call.
class CallAppSettings {
  /// The `appId` of the call.
  final String? appId;

  /// The `region` of the call.
  final String? region;

  /// The `host` of the call.
  final String? host;

  /// A private constructor used by the `CallAppSettingBuilder` to create an instance of `CallAppSettings`.
  CallAppSettings._builder(CallAppSettingBuilder builder)
      : appId = builder.appId,
        region = builder.region,
        host = builder.host;
}

/// `CallAppSettingBuilder` is a builder class for `CallAppSettings`.
///
/// Use this class to create an instance of `CallAppSettings`.
class CallAppSettingBuilder {
  /// The `appId` of the call.
  String? appId;

  /// The `region` of the call.
  String? region;

  /// The `host` of the call.
  String? host;

  /// Default constructor for `CallAppSettingBuilder`.
  CallAppSettingBuilder();

  /// Builds an instance of `CallAppSettings` with the parameters set in this builder.
  CallAppSettings build() {
    return CallAppSettings._builder(this);
  }
}
