import 'package:cometchat_calls_sdk/cometchat_calls_sdk.dart';

/// `CallSettings` is a class that contains the various settings for a call.
class CallSettings {
  bool? defaultLayout;
  bool? isAudioOnly;
  bool? isSingleMode;
  bool? showSwitchToVideoCall;
  bool? enableVideoTileClick;
  bool? enableDraggableVideoTile;
  bool? endCallButtonDisable;
  bool? showRecordingButton;
  bool? startRecordingOnCallStart;
  bool? switchCameraButtonDisable;
  bool? muteAudioButtonDisable;
  bool? pauseVideoButtonDisable;
  bool? audioModeButtonDisable;
  bool? startAudioMuted;
  bool? startVideoMuted;
  AvatarModes? avatarMode;
  Mode? mode;
  AudioModes? defaultAudioMode;
  MainVideoContainerSetting? videoSettings;
  CometChatCallsEventsListener? listener;

  /// A private constructor used by the `CallSettingsBuilder` to create an instance of `CallSettings`.
  CallSettings._builder(CallSettingsBuilder builder)
      : defaultLayout = builder.enableDefaultLayout,
        isAudioOnly = builder.setAudioOnlyCall,
        isSingleMode = builder.setSingleMode,
        showSwitchToVideoCall = builder.showSwitchToVideoCallButton,
        enableVideoTileClick = builder.enableVideoTileClick,
        enableDraggableVideoTile = builder.enableVideoTileDrag,
        endCallButtonDisable = builder.showEndCallButton,
        showRecordingButton = builder.showCallRecordButton,
        startRecordingOnCallStart = builder.startRecordingOnCallStart,
        switchCameraButtonDisable = builder.showSwitchCameraButton,
        muteAudioButtonDisable = builder.showMuteAudioButton,
        pauseVideoButtonDisable = builder.showPauseVideoButton,
        audioModeButtonDisable = builder.showAudioModeButton,
        startAudioMuted = builder.startWithAudioMuted,
        startVideoMuted = builder.startWithVideoMuted,
        avatarMode = builder.setAvatarMode,
        mode = builder.setMode,
        defaultAudioMode = builder.setDefaultAudioMode,
        videoSettings = builder.setMainVideoContainerSetting,
        listener = builder.listener;
}

/// `CallSettingsBuilder` is a builder class for `CallSettings`.
///
/// Use this class to create an instance of `CallSettings`.
class CallSettingsBuilder {
  bool? enableDefaultLayout;
  bool? setAudioOnlyCall;
  bool? setSingleMode;
  bool? showSwitchToVideoCallButton;
  bool? enableVideoTileClick;
  bool? enableVideoTileDrag;
  bool? showEndCallButton;
  bool? showCallRecordButton;
  bool? startRecordingOnCallStart;
  bool? showSwitchCameraButton;
  bool? showMuteAudioButton;
  bool? showPauseVideoButton;
  bool? showAudioModeButton;
  bool? startWithAudioMuted;
  bool? startWithVideoMuted;
  AvatarModes? setAvatarMode;
  Mode? setMode;
  AudioModes? setDefaultAudioMode;
  MainVideoContainerSetting? setMainVideoContainerSetting;
  CometChatCallsEventsListener? listener;

  /// Default constructor for `CallSettingsBuilder`.
  CallSettingsBuilder();

  /// Builds an instance of `CallSettings` with the parameters set in this builder.
  CallSettings build() {
    return CallSettings._builder(this);
  }
}
